import OCP.StepAP209
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.StepFEA
import OCP.StepData
import OCP.STEPConstruct
import OCP.StepShape
import OCP.XSControl
import OCP.Interface
import OCP.StepRepr
import OCP.StepElement
import OCP.StepBasic
import OCP.Transfer
__all__  = [
"StepAP209_Construct"
]
class StepAP209_Construct(OCP.STEPConstruct.STEPConstruct_Tool):
    """
    Basic tool for working with AP209 model
    """
    def CreateAP203Structure(self) -> OCP.StepData.StepData_StepModel: 
        """
        Create AP203 structure from existing AP209 structure
        """
    def CreateAdding203Entities(self,PD : OCP.StepBasic.StepBasic_ProductDefinition,aModel : OCP.StepData.StepData_StepModel) -> bool: 
        """
        Create approval.. , date.. , time.. , person.. and organization.. entities for 203 structure
        """
    def CreateAddingEntities(self,AnaPD : OCP.StepBasic.StepBasic_ProductDefinition) -> bool: 
        """
        Create approval.. , date.. , time.. , person.. and organization.. entities for analysis structure
        """
    def CreateAnalysStructure(self,Prod : OCP.StepBasic.StepBasic_Product) -> bool: 
        """
        Create empty structure for idealized_analysis_shape
        """
    def CreateFeaStructure(self,Prod : OCP.StepBasic.StepBasic_Product) -> bool: 
        """
        Create fea structure
        """
    @overload
    def FeaModel(self,Prod : OCP.StepBasic.StepBasic_Product) -> OCP.StepFEA.StepFEA_FeaModel: ...
    @overload
    def FeaModel(self,PDF : OCP.StepBasic.StepBasic_ProductDefinitionFormation) -> OCP.StepFEA.StepFEA_FeaModel: ...
    @overload
    def FeaModel(self,PDS : OCP.StepRepr.StepRepr_ProductDefinitionShape) -> OCP.StepFEA.StepFEA_FeaModel: ...
    @overload
    def FeaModel(self,PD : OCP.StepBasic.StepBasic_ProductDefinition) -> OCP.StepFEA.StepFEA_FeaModel: ...
    def FinderProcess(self) -> OCP.Transfer.Transfer_FinderProcess: 
        """
        Returns FinderProcess (writing; Null if not loaded)

        Returns FinderProcess (writing; Null if not loaded)
        """
    def GetCurElemSection(self,ElemRepr : OCP.StepFEA.StepFEA_Curve3dElementRepresentation) -> OCP.StepElement.StepElement_HSequenceOfCurveElementSectionDefinition: 
        """
        Getting list of curve_element_section_definitions for given element_representation
        """
    def GetElemGeomRelat(self) -> OCP.StepFEA.StepFEA_HSequenceOfElementGeometricRelationship: ...
    def GetElementMaterial(self) -> OCP.StepElement.StepElement_HSequenceOfElementMaterial: ...
    def GetElements1D(self,theFeaModel : OCP.StepFEA.StepFEA_FeaModel) -> OCP.StepFEA.StepFEA_HSequenceOfElementRepresentation: ...
    def GetElements2D(self,theFEAModel : OCP.StepFEA.StepFEA_FeaModel) -> OCP.StepFEA.StepFEA_HSequenceOfElementRepresentation: ...
    def GetElements3D(self,theFEAModel : OCP.StepFEA.StepFEA_FeaModel) -> OCP.StepFEA.StepFEA_HSequenceOfElementRepresentation: ...
    def GetFeaAxis2Placement3d(self,theFeaModel : OCP.StepFEA.StepFEA_FeaModel) -> OCP.StepFEA.StepFEA_FeaAxis2Placement3d: ...
    def GetShReprForElem(self,ElemRepr : OCP.StepFEA.StepFEA_ElementRepresentation) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    @overload
    def Graph(self,recompute : bool=False) -> OCP.Interface.Interface_Graph: 
        """
        Returns current graph (recomputing if necessary)

        Returns current graph (recomputing if necessary)
        """
    @overload
    def Graph(self,recompute : bool) -> OCP.Interface.Interface_Graph: ...
    @overload
    def IdealShape(self,Prod : OCP.StepBasic.StepBasic_Product) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    @overload
    def IdealShape(self,PDF : OCP.StepBasic.StepBasic_ProductDefinitionFormation) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    @overload
    def IdealShape(self,PD : OCP.StepBasic.StepBasic_ProductDefinition) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    @overload
    def IdealShape(self,PDS : OCP.StepRepr.StepRepr_ProductDefinitionShape) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    def Init(self,WS : OCP.XSControl.XSControl_WorkSession) -> bool: 
        """
        Initializes tool; returns True if succeeded
        """
    def IsAnalys(self,PD : OCP.StepBasic.StepBasic_ProductDefinitionFormation) -> bool: ...
    def IsDesing(self,PD : OCP.StepBasic.StepBasic_ProductDefinitionFormation) -> bool: ...
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns current model (Null if not loaded)

        Returns current model (Null if not loaded)
        """
    @overload
    def NominShape(self,Prod : OCP.StepBasic.StepBasic_Product) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    @overload
    def NominShape(self,PDF : OCP.StepBasic.StepBasic_ProductDefinitionFormation) -> OCP.StepShape.StepShape_ShapeRepresentation: ...
    def ReplaceCcDesingToApplied(self) -> bool: 
        """
        Put into model entities Applied... for AP209 instead of entities CcDesing... from AP203.
        """
    def TransientProcess(self) -> OCP.Transfer.Transfer_TransientProcess: 
        """
        Returns TransientProcess (reading; Null if not loaded)

        Returns TransientProcess (reading; Null if not loaded)
        """
    def WS(self) -> OCP.XSControl.XSControl_WorkSession: 
        """
        Returns currently loaded WorkSession

        Returns currently loaded WorkSession
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,WS : OCP.XSControl.XSControl_WorkSession) -> None: ...
    pass



import OCP.VrmlAPI
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.Quantity
import OCP.gp
import OCP.TopoDS
import OCP.TColStd
import OCP.Message
import OCP.TDocStd
import OCP.Standard
import OCP.Interface
import OCP.RWMesh
import OCP.Vrml
__all__  = [
"VrmlAPI",
"VrmlAPI_CafReader",
"VrmlAPI_RepresentationOfShape",
"VrmlAPI_Writer",
"VrmlAPI_BothRepresentation",
"VrmlAPI_ShadedRepresentation",
"VrmlAPI_WireFrameRepresentation"
]
class VrmlAPI():
    """
    API for writing to VRML 1.0
    """
    @staticmethod
    def Write_s(aShape : OCP.TopoDS.TopoDS_Shape,aFileName : str,aVersion : int=2) -> bool: 
        """
        With help of this class user can change parameters of writing. Converts the shape aShape to VRML format of the passed version and writes it to the file identified by aFileName using default parameters.
        """
    def __init__(self) -> None: ...
    pass
class VrmlAPI_CafReader(OCP.RWMesh.RWMesh_CafReader, OCP.Standard.Standard_Transient):
    """
    The Vrml mesh reader into XDE document.
    """
    def CoordinateSystemConverter(self) -> OCP.RWMesh.RWMesh_CoordinateSystemConverter: 
        """
        Return coordinate system converter.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Document(self) -> OCP.TDocStd.TDocStd_Document: 
        """
        Return target document.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def ExternalFiles(self) -> OCP.Interface.Interface_IndexedMapOfAsciiString: 
        """
        Return the list of complementary files - external references (textures, data, etc.).
        """
    def ExtraStatus(self) -> int: 
        """
        Return extended status flags.
        """
    def FileCoordinateSystem(self) -> OCP.gp.gp_Ax3: 
        """
        Return file origin coordinate system; can be UNDEFINED, which means no conversion will be done.
        """
    def FileLengthUnit(self) -> float: 
        """
        Return the length unit to convert from while reading the file, defined as scale factor for m (meters). Can be undefined (-1.0) if file format is unitless.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasFileCoordinateSystem(self) -> bool: 
        """
        Return TRUE if file origin coordinate system has been defined.
        """
    def HasSystemCoordinateSystem(self) -> bool: 
        """
        Return TRUE if system coordinate system has been defined; FALSE by default.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MemoryLimitMiB(self) -> int: 
        """
        Return memory usage limit in MiB, -1 by default which means no limit.
        """
    def Metadata(self) -> OCP.TColStd.TColStd_IndexedDataMapOfStringString: 
        """
        Return metadata map.
        """
    @overload
    def Perform(self,theFile : OCP.TCollection.TCollection_AsciiString,theProgress : OCP.Message.Message_ProgressRange) -> bool: 
        """
        Open stream and pass it to Perform method. The Document instance should be set beforehand.

        Read the data from specified file.
        """
    @overload
    def Perform(self,theStream : io.BytesIO,theProgress : OCP.Message.Message_ProgressRange,theFile : OCP.TCollection.TCollection_AsciiString=OCP.TCollection.TCollection_AsciiString) -> bool: ...
    @overload
    def ProbeHeader(self,theFile : OCP.TCollection.TCollection_AsciiString,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Open stream and pass it to ProbeHeader method.

        Read the header data from specified file without reading entire model. The main purpose is collecting metadata and external references - for copying model into a new location, for example. Can be NOT implemented (unsupported by format / reader).
        """
    @overload
    def ProbeHeader(self,theStream : io.BytesIO,theFile : OCP.TCollection.TCollection_AsciiString=OCP.TCollection.TCollection_AsciiString,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: ...
    def RootPrefix(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Return prefix for generating root labels names.
        """
    def SetCoordinateSystemConverter(self,theConverter : OCP.RWMesh.RWMesh_CoordinateSystemConverter) -> None: 
        """
        Set coordinate system converter.
        """
    def SetDocument(self,theDoc : OCP.TDocStd.TDocStd_Document) -> None: 
        """
        Set target document. Set system length unit according to the units of the document
        """
    @overload
    def SetFileCoordinateSystem(self,theCS : OCP.gp.gp_Ax3) -> None: ...
    @overload
    def SetFileCoordinateSystem(self,theCS : OCP.RWMesh.RWMesh_CoordinateSystem) -> None: ...
    def SetFileLengthUnit(self,theUnits : float) -> None: ...
    def SetFillIncompleteDocument(self,theToFillIncomplete : bool) -> None: 
        """
        Set flag allowing partially read file content to be put into the XDE document.
        """
    def SetMemoryLimitMiB(self,theLimitMiB : int) -> None: 
        """
        Set memory usage limit in MiB; can be ignored by reader implementation!
        """
    def SetRootPrefix(self,theRootPrefix : OCP.TCollection.TCollection_AsciiString) -> None: 
        """
        Set prefix for generating root labels names
        """
    @overload
    def SetSystemCoordinateSystem(self,theCS : OCP.gp.gp_Ax3) -> None: 
        """
        Set system origin coordinate system to perform conversion into during read.

        Set system origin coordinate system to perform conversion into during read.
        """
    @overload
    def SetSystemCoordinateSystem(self,theCS : OCP.RWMesh.RWMesh_CoordinateSystem) -> None: ...
    def SetSystemLengthUnit(self,theUnits : float) -> None: 
        """
        Set system length units to convert into while reading the file, defined as scale factor for m (meters).
        """
    def SingleShape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Return result as a single shape.
        """
    def SystemCoordinateSystem(self) -> OCP.gp.gp_Ax3: 
        """
        Return system coordinate system; UNDEFINED by default, which means that no conversion will be done.
        """
    def SystemLengthUnit(self) -> float: 
        """
        Return the length unit to convert into while reading the file, defined as scale factor for m (meters); -1.0 by default, which means that NO conversion will be applied.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToFillIncompleteDocument(self) -> bool: 
        """
        Flag indicating if partially read file content should be put into the XDE document, TRUE by default.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class VrmlAPI_RepresentationOfShape():
    """
    Identifies the representation of the shape written to a VRML file. The available options are : - VrmlAPI_ShadedRepresentation : the shape is translated with a shaded representation. - VrmlAPI_WireFrameRepresentation : the shape is translated with a wireframe representation. - VrmlAPI_BothRepresentation : the shape is translated to VRML format with both representations : shaded and wireframe. This is the default option.

    Members:

      VrmlAPI_ShadedRepresentation

      VrmlAPI_WireFrameRepresentation

      VrmlAPI_BothRepresentation
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    VrmlAPI_BothRepresentation: OCP.VrmlAPI.VrmlAPI_RepresentationOfShape # value = <VrmlAPI_RepresentationOfShape.VrmlAPI_BothRepresentation: 2>
    VrmlAPI_ShadedRepresentation: OCP.VrmlAPI.VrmlAPI_RepresentationOfShape # value = <VrmlAPI_RepresentationOfShape.VrmlAPI_ShadedRepresentation: 0>
    VrmlAPI_WireFrameRepresentation: OCP.VrmlAPI.VrmlAPI_RepresentationOfShape # value = <VrmlAPI_RepresentationOfShape.VrmlAPI_WireFrameRepresentation: 1>
    __entries: dict # value = {'VrmlAPI_ShadedRepresentation': (<VrmlAPI_RepresentationOfShape.VrmlAPI_ShadedRepresentation: 0>, None), 'VrmlAPI_WireFrameRepresentation': (<VrmlAPI_RepresentationOfShape.VrmlAPI_WireFrameRepresentation: 1>, None), 'VrmlAPI_BothRepresentation': (<VrmlAPI_RepresentationOfShape.VrmlAPI_BothRepresentation: 2>, None)}
    __members__: dict # value = {'VrmlAPI_ShadedRepresentation': <VrmlAPI_RepresentationOfShape.VrmlAPI_ShadedRepresentation: 0>, 'VrmlAPI_WireFrameRepresentation': <VrmlAPI_RepresentationOfShape.VrmlAPI_WireFrameRepresentation: 1>, 'VrmlAPI_BothRepresentation': <VrmlAPI_RepresentationOfShape.VrmlAPI_BothRepresentation: 2>}
    pass
class VrmlAPI_Writer():
    """
    Creates and writes VRML files from Open CASCADE shapes. A VRML file can be written to an existing VRML file or to a new one.
    """
    def Drawer(self) -> VrmlConverter_Drawer: 
        """
        Returns drawer object
        """
    def GetFreeBoundsMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetFrontMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetLineMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetPointsMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetRepresentation(self) -> VrmlAPI_RepresentationOfShape: 
        """
        Returns the representation of the shape which is written to the VRML file. Types of representation are set through the VrmlAPI_RepresentationOfShape enumeration.
        """
    def GetUisoMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetUnfreeBoundsMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetVisoMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def GetWireMaterial(self) -> OCP.Vrml.Vrml_Material: ...
    def ResetToDefaults(self) -> None: 
        """
        Resets all parameters (representation, deflection) to their default values..
        """
    def SetAmbientColorToMaterial(self,aMaterial : OCP.Vrml.Vrml_Material,Color : OCP.Quantity.Quantity_HArray1OfColor) -> Any: ...
    def SetDeflection(self,aDef : float) -> None: 
        """
        Sets the deflection aDef of the mesh algorithm which is used to compute the shaded representation of the translated shape. The default value is -1. When the deflection value is less than 0, the deflection is calculated from the relative size of the shaped.
        """
    def SetDiffuseColorToMaterial(self,aMaterial : OCP.Vrml.Vrml_Material,Color : OCP.Quantity.Quantity_HArray1OfColor) -> Any: ...
    def SetEmissiveColorToMaterial(self,aMaterial : OCP.Vrml.Vrml_Material,Color : OCP.Quantity.Quantity_HArray1OfColor) -> Any: ...
    def SetRepresentation(self,aRep : VrmlAPI_RepresentationOfShape) -> None: 
        """
        Sets the representation of the shape aRep which is written to the VRML file. The three options are : - shaded - wireframe - both shaded and wireframe (default) defined through the VrmlAPI_RepresentationOfShape enumeration.
        """
    def SetShininessToMaterial(self,aMaterial : OCP.Vrml.Vrml_Material,aShininess : float) -> Any: ...
    def SetSpecularColorToMaterial(self,aMaterial : OCP.Vrml.Vrml_Material,Color : OCP.Quantity.Quantity_HArray1OfColor) -> Any: ...
    def SetTransparencyToMaterial(self,aMaterial : OCP.Vrml.Vrml_Material,aTransparency : float) -> Any: 
        """
        Set transparency to given material
        """
    def Write(self,aShape : OCP.TopoDS.TopoDS_Shape,aFile : str,aVersion : int=2) -> bool: 
        """
        Converts the shape aShape to VRML format of the passed version and writes it to the file identified by aFile.
        """
    def WriteDoc(self,theDoc : OCP.TDocStd.TDocStd_Document,theFile : str,theScale : float) -> bool: 
        """
        Converts the document to VRML format of the passed version and writes it to the file identified by aFile.
        """
    def __init__(self) -> None: ...
    pass
VrmlAPI_BothRepresentation: OCP.VrmlAPI.VrmlAPI_RepresentationOfShape # value = <VrmlAPI_RepresentationOfShape.VrmlAPI_BothRepresentation: 2>
VrmlAPI_ShadedRepresentation: OCP.VrmlAPI.VrmlAPI_RepresentationOfShape # value = <VrmlAPI_RepresentationOfShape.VrmlAPI_ShadedRepresentation: 0>
VrmlAPI_WireFrameRepresentation: OCP.VrmlAPI.VrmlAPI_RepresentationOfShape # value = <VrmlAPI_RepresentationOfShape.VrmlAPI_WireFrameRepresentation: 1>



import OCP.BinTObjDrivers
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.PCDM
import OCP.Storage
import OCP.TColStd
import OCP.Message
import OCP.CDM
import OCP.BinMDF
import OCP.TDocStd
import OCP.Standard
import OCP.TDF
import OCP.BinLDrivers
import OCP.BinObjMgt
__all__  = [
"BinTObjDrivers",
"BinTObjDrivers_DocumentRetrievalDriver",
"BinTObjDrivers_DocumentStorageDriver",
"BinTObjDrivers_IntSparseArrayDriver",
"BinTObjDrivers_ModelDriver",
"BinTObjDrivers_ObjectDriver",
"BinTObjDrivers_ReferenceDriver",
"BinTObjDrivers_XYZDriver"
]
class BinTObjDrivers():
    """
    Class for registering storage/retrieval drivers for TObj Bin persistence
    """
    @staticmethod
    def AddDrivers_s(aDriverTable : OCP.BinMDF.BinMDF_ADriverTable,aMsgDrv : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def DefineFormat_s(theApp : OCP.TDocStd.TDocStd_Application) -> None: 
        """
        Defines format "TObjBin" and registers its read and write drivers in the specified application
        """
    @staticmethod
    def Factory_s(aGUID : OCP.Standard.Standard_GUID) -> OCP.Standard.Standard_Transient: ...
    def __init__(self) -> None: ...
    pass
class BinTObjDrivers_DocumentRetrievalDriver(OCP.BinLDrivers.BinLDrivers_DocumentRetrievalDriver, OCP.PCDM.PCDM_RetrievalDriver, OCP.PCDM.PCDM_Reader, OCP.Standard.Standard_Transient):
    def AttributeDrivers(self,theMsgDriver : OCP.Message.Message_Messenger) -> OCP.BinMDF.BinMDF_ADriverTable: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @staticmethod
    def DocumentVersion_s(theFileName : OCP.TCollection.TCollection_ExtendedString,theMsgDriver : OCP.Message.Message_Messenger) -> int: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetFormat(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStatus(self) -> OCP.PCDM.PCDM_ReaderStatus: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @overload
    def Read(self,theFileName : OCP.TCollection.TCollection_ExtendedString,theNewDocument : OCP.CDM.CDM_Document,theApplication : OCP.CDM.CDM_Application,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        retrieves the content of the file into a new Document.
        """
    @overload
    def Read(self,theIStream : io.BytesIO,theStorageData : OCP.Storage.Storage_Data,theDoc : OCP.CDM.CDM_Document,theApplication : OCP.CDM.CDM_Application,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    @staticmethod
    def ReferenceCounter_s(theFileName : OCP.TCollection.TCollection_ExtendedString,theMsgDriver : OCP.Message.Message_Messenger) -> int: ...
    def SetFormat(self,aformat : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BinTObjDrivers_DocumentStorageDriver(OCP.BinLDrivers.BinLDrivers_DocumentStorageDriver, OCP.PCDM.PCDM_StorageDriver, OCP.PCDM.PCDM_Writer, OCP.Standard.Standard_Transient):
    def AddSection(self,theName : OCP.TCollection.TCollection_AsciiString,isPostRead : bool=True) -> None: 
        """
        Create a section that should be written after the OCAF data
        """
    def AttributeDrivers(self,theMsgDriver : OCP.Message.Message_Messenger) -> OCP.BinMDF.BinMDF_ADriverTable: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetFormat(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStoreStatus(self) -> OCP.PCDM.PCDM_StoreStatus: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsError(self) -> bool: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsQuickPart(self,theVersion : int) -> bool: 
        """
        Return true if document should be stored in quick mode for partial reading
        """
    @overload
    def Make(self,aDocument : OCP.CDM.CDM_Document) -> OCP.PCDM.PCDM_Document: 
        """
        raises NotImplemented.

        By default, puts in the Sequence the document returns by the previous Make method.
        """
    @overload
    def Make(self,aDocument : OCP.CDM.CDM_Document,Documents : OCP.PCDM.PCDM_SequenceOfDocument) -> None: ...
    def SetFormat(self,aformat : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    def SetIsError(self,theIsError : bool) -> None: ...
    def SetStoreStatus(self,theStoreStatus : OCP.PCDM.PCDM_StoreStatus) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def Write(self,theDocument : OCP.CDM.CDM_Document,theFileName : OCP.TCollection.TCollection_ExtendedString,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: 
        """
        Write <theDocument> to the binary file <theFileName>

        Write <theDocument> to theOStream
        """
    @overload
    def Write(self,theDocument : OCP.CDM.CDM_Document,theOStream : io.BytesIO,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BinTObjDrivers_IntSparseArrayDriver(OCP.BinMDF.BinMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,theSource : OCP.BinObjMgt.BinObjMgt_Persistent,theTarget : OCP.TDF.TDF_Attribute,theRelocTable : OCP.BinObjMgt.BinObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,theSource : OCP.TDF.TDF_Attribute,theTarget : OCP.BinObjMgt.BinObjMgt_Persistent,theRelocTable : OCP.TColStd.TColStd_IndexedMapOfTransient) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the type name of the attribute object

        Returns the type name of the attribute object
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BinTObjDrivers_ModelDriver(OCP.BinMDF.BinMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.BinObjMgt.BinObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.BinObjMgt.BinObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.BinObjMgt.BinObjMgt_Persistent,RelocTable : OCP.TColStd.TColStd_IndexedMapOfTransient) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the type name of the attribute object

        Returns the type name of the attribute object
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BinTObjDrivers_ObjectDriver(OCP.BinMDF.BinMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.BinObjMgt.BinObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.BinObjMgt.BinObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.BinObjMgt.BinObjMgt_Persistent,RelocTable : OCP.TColStd.TColStd_IndexedMapOfTransient) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the type name of the attribute object

        Returns the type name of the attribute object
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BinTObjDrivers_ReferenceDriver(OCP.BinMDF.BinMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.BinObjMgt.BinObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.BinObjMgt.BinObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.BinObjMgt.BinObjMgt_Persistent,RelocTable : OCP.TColStd.TColStd_IndexedMapOfTransient) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the type name of the attribute object

        Returns the type name of the attribute object
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BinTObjDrivers_XYZDriver(OCP.BinMDF.BinMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,theSource : OCP.BinObjMgt.BinObjMgt_Persistent,theTarget : OCP.TDF.TDF_Attribute,theRelocTable : OCP.BinObjMgt.BinObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,theSource : OCP.TDF.TDF_Attribute,theTarget : OCP.BinObjMgt.BinObjMgt_Persistent,theRelocTable : OCP.TColStd.TColStd_IndexedMapOfTransient) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the type name of the attribute object

        Returns the type name of the attribute object
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.IntStart
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import OCP.TopAbs
import OCP.gp
__all__  = [
"IntStart_SITopolTool"
]
class IntStart_SITopolTool(OCP.Standard.Standard_Transient):
    """
    template class for a topological tool. This tool is linked with the surface on which the classification has to be made.template class for a topological tool. This tool is linked with the surface on which the classification has to be made.template class for a topological tool. This tool is linked with the surface on which the classification has to be made.
    """
    def Classify(self,P : OCP.gp.gp_Pnt2d,Tol : float) -> OCP.TopAbs.TopAbs_State: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.AppBlend
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TColStd
import OCP.TColgp
__all__  = [
"AppBlend_Approx"
]
class AppBlend_Approx():
    """
    Bspline approximation of a surface.
    """
    def Curve2d(self,Index : int,TPoles : OCP.TColgp.TColgp_Array1OfPnt2d,TKnots : OCP.TColStd.TColStd_Array1OfReal,TMults : OCP.TColStd.TColStd_Array1OfInteger) -> None: ...
    def Curve2dPoles(self,Index : int) -> OCP.TColgp.TColgp_Array1OfPnt2d: ...
    def Curves2dDegree(self) -> int: ...
    def Curves2dKnots(self) -> OCP.TColStd.TColStd_Array1OfReal: ...
    def Curves2dMults(self) -> OCP.TColStd.TColStd_Array1OfInteger: ...
    def Curves2dShape(self) -> tuple[int, int, int]: ...
    def IsDone(self) -> bool: ...
    def NbCurves2d(self) -> int: ...
    def SurfPoles(self) -> OCP.TColgp.TColgp_Array2OfPnt: ...
    def SurfShape(self) -> tuple[int, int, int, int, int, int]: ...
    def SurfUKnots(self) -> OCP.TColStd.TColStd_Array1OfReal: ...
    def SurfUMults(self) -> OCP.TColStd.TColStd_Array1OfInteger: ...
    def SurfVKnots(self) -> OCP.TColStd.TColStd_Array1OfReal: ...
    def SurfVMults(self) -> OCP.TColStd.TColStd_Array1OfInteger: ...
    def SurfWeights(self) -> OCP.TColStd.TColStd_Array2OfReal: ...
    def Surface(self,TPoles : OCP.TColgp.TColgp_Array2OfPnt,TWeights : OCP.TColStd.TColStd_Array2OfReal,TUKnots : OCP.TColStd.TColStd_Array1OfReal,TVKnots : OCP.TColStd.TColStd_Array1OfReal,TUMults : OCP.TColStd.TColStd_Array1OfInteger,TVMults : OCP.TColStd.TColStd_Array1OfInteger) -> None: ...
    def TolCurveOnSurf(self,Index : int) -> float: ...
    def TolReached(self) -> tuple[float, float]: ...
    def UDegree(self) -> int: ...
    def VDegree(self) -> int: ...
    pass



import OCP.CSLib
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.math
import OCP.TColStd
import OCP.gp
import OCP.TColgp
__all__  = [
"CSLib",
"CSLib_Class2d",
"CSLib_DerivativeStatus",
"CSLib_NormalPolyDef",
"CSLib_NormalStatus",
"CSLib_D1IsNull",
"CSLib_D1NIsNull",
"CSLib_D1NuIsNull",
"CSLib_D1NuIsParallelD1Nv",
"CSLib_D1NuNvRatioIsNull",
"CSLib_D1NvIsNull",
"CSLib_D1NvNuRatioIsNull",
"CSLib_D1uD1vRatioIsNull",
"CSLib_D1uIsNull",
"CSLib_D1uIsParallelD1v",
"CSLib_D1vD1uRatioIsNull",
"CSLib_D1vIsNull",
"CSLib_Defined",
"CSLib_Done",
"CSLib_InfinityOfSolutions",
"CSLib_Singular"
]
class CSLib():
    """
    This package implements functions for basis geometric computation on curves and surfaces. The tolerance criterions used in this package are Resolution from package gp and RealEpsilon from class Real of package Standard.
    """
    @staticmethod
    @overload
    def DNNUV_s(Nu : int,Nv : int,DerSurf : OCP.TColgp.TColgp_Array2OfVec) -> OCP.gp.gp_Vec: 
        """
        -- Computes the derivative of order Nu in the -- direction U and Nv in the direction V of the not -- normalized normal vector at the point P(U,V) The array DerSurf contain the derivative (i,j) of the surface for i=0,Nu+1 ; j=0,Nv+1

        Computes the derivatives of order Nu in the direction Nu and Nv in the direction Nv of the not normalized vector N(u,v) = dS1/du * dS2/dv (cases where we use an osculating surface) DerSurf1 are the derivatives of S1
        """
    @staticmethod
    @overload
    def DNNUV_s(Nu : int,Nv : int,DerSurf1 : OCP.TColgp.TColgp_Array2OfVec,DerSurf2 : OCP.TColgp.TColgp_Array2OfVec) -> OCP.gp.gp_Vec: ...
    @staticmethod
    def DNNormal_s(Nu : int,Nv : int,DerNUV : OCP.TColgp.TColgp_Array2OfVec,Iduref : int=0,Idvref : int=0) -> OCP.gp.gp_Vec: 
        """
        -- Computes the derivative of order Nu in the -- direction U and Nv in the direction V of the normalized normal vector at the point P(U,V) array DerNUV contain the derivative (i+Iduref,j+Idvref) of D1U ^ D1V for i=0,Nu ; j=0,Nv Iduref and Idvref correspond to a derivative of D1U ^ D1V which can be used to compute the normalized normal vector. In the regular cases , Iduref=Idvref=0.
        """
    @staticmethod
    @overload
    def Normal_s(D1U : OCP.gp.gp_Vec,D1V : OCP.gp.gp_Vec,SinTol : float,theStatus : CSLib_DerivativeStatus,Normal : OCP.gp.gp_Dir) -> None: 
        """
        The following functions computes the normal to a surface inherits FunctionWithDerivative from math

        Computes the normal direction of a surface as the cross product between D1U and D1V.

        If there is a singularity on the surface the previous method cannot compute the local normal. This method computes an approached normal direction of a surface. It does a limited development and needs the second derivatives on the surface as input data. It computes the normal as follow : N(u, v) = D1U ^ D1V N(u0+du,v0+dv) = N0 + DN/du(u0,v0) * du + DN/dv(u0,v0) * dv + Eps with Eps->0 so we can have the equivalence N ~ dN/du + dN/dv. DNu = ||DN/du|| and DNv = ||DN/dv||

        find the first order k0 of deriviative of NUV where: foreach order < k0 all the derivatives of NUV are null all the derivatives of NUV corresponding to the order k0 are collinear and have the same sens. In this case, normal at U,V is unique.
        """
    @staticmethod
    @overload
    def Normal_s(D1U : OCP.gp.gp_Vec,D1V : OCP.gp.gp_Vec,MagTol : float,theStatus : CSLib_NormalStatus,Normal : OCP.gp.gp_Dir) -> None: ...
    @staticmethod
    @overload
    def Normal_s(D1U : OCP.gp.gp_Vec,D1V : OCP.gp.gp_Vec,D2U : OCP.gp.gp_Vec,D2V : OCP.gp.gp_Vec,D2UV : OCP.gp.gp_Vec,SinTol : float,theStatus : CSLib_NormalStatus,Normal : OCP.gp.gp_Dir) -> tuple[bool]: ...
    @staticmethod
    @overload
    def Normal_s(MaxOrder : int,DerNUV : OCP.TColgp.TColgp_Array2OfVec,MagTol : float,U : float,V : float,Umin : float,Umax : float,Vmin : float,Vmax : float,theStatus : CSLib_NormalStatus,Normal : OCP.gp.gp_Dir) -> tuple[int, int]: ...
    def __init__(self) -> None: ...
    pass
class CSLib_Class2d():
    """
    *** Class2d : Low level algorithm for 2d classification this class was moved from package BRepTopAdaptor
    """
    def InternalSiDans(self,X : float,Y : float) -> int: ...
    def InternalSiDansOuOn(self,X : float,Y : float) -> int: ...
    def SiDans(self,P : OCP.gp.gp_Pnt2d) -> int: ...
    def SiDans_OnMode(self,P : OCP.gp.gp_Pnt2d,Tol : float) -> int: ...
    @overload
    def __init__(self,thePnts2d : OCP.TColgp.TColgp_Array1OfPnt2d,theTolU : float,theTolV : float,theUMin : float,theVMin : float,theUMax : float,theVMax : float) -> None: ...
    @overload
    def __init__(self,thePnts2d : OCP.TColgp.TColgp_SequenceOfPnt2d,theTolU : float,theTolV : float,theUMin : float,theVMin : float,theUMax : float,theVMax : float) -> None: ...
    pass
class CSLib_DerivativeStatus():
    """
    D1uIsNull : ||D1U|| <= Resolution

    Members:

      CSLib_Done

      CSLib_D1uIsNull

      CSLib_D1vIsNull

      CSLib_D1IsNull

      CSLib_D1uD1vRatioIsNull

      CSLib_D1vD1uRatioIsNull

      CSLib_D1uIsParallelD1v
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CSLib_D1IsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1IsNull: 3>
    CSLib_D1uD1vRatioIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1uD1vRatioIsNull: 4>
    CSLib_D1uIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1uIsNull: 1>
    CSLib_D1uIsParallelD1v: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1uIsParallelD1v: 6>
    CSLib_D1vD1uRatioIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1vD1uRatioIsNull: 5>
    CSLib_D1vIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1vIsNull: 2>
    CSLib_Done: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_Done: 0>
    __entries: dict # value = {'CSLib_Done': (<CSLib_DerivativeStatus.CSLib_Done: 0>, None), 'CSLib_D1uIsNull': (<CSLib_DerivativeStatus.CSLib_D1uIsNull: 1>, None), 'CSLib_D1vIsNull': (<CSLib_DerivativeStatus.CSLib_D1vIsNull: 2>, None), 'CSLib_D1IsNull': (<CSLib_DerivativeStatus.CSLib_D1IsNull: 3>, None), 'CSLib_D1uD1vRatioIsNull': (<CSLib_DerivativeStatus.CSLib_D1uD1vRatioIsNull: 4>, None), 'CSLib_D1vD1uRatioIsNull': (<CSLib_DerivativeStatus.CSLib_D1vD1uRatioIsNull: 5>, None), 'CSLib_D1uIsParallelD1v': (<CSLib_DerivativeStatus.CSLib_D1uIsParallelD1v: 6>, None)}
    __members__: dict # value = {'CSLib_Done': <CSLib_DerivativeStatus.CSLib_Done: 0>, 'CSLib_D1uIsNull': <CSLib_DerivativeStatus.CSLib_D1uIsNull: 1>, 'CSLib_D1vIsNull': <CSLib_DerivativeStatus.CSLib_D1vIsNull: 2>, 'CSLib_D1IsNull': <CSLib_DerivativeStatus.CSLib_D1IsNull: 3>, 'CSLib_D1uD1vRatioIsNull': <CSLib_DerivativeStatus.CSLib_D1uD1vRatioIsNull: 4>, 'CSLib_D1vD1uRatioIsNull': <CSLib_DerivativeStatus.CSLib_D1vD1uRatioIsNull: 5>, 'CSLib_D1uIsParallelD1v': <CSLib_DerivativeStatus.CSLib_D1uIsParallelD1v: 6>}
    pass
class CSLib_NormalPolyDef(OCP.math.math_FunctionWithDerivative, OCP.math.math_Function):
    def Derivative(self,X : float,D : float) -> bool: 
        """
        computes the derivative <D> of the function for the variable <X>. Returns True if the calculation were successfully done, False otherwise.
        """
    def GetStateNumber(self) -> int: 
        """
        returns the state of the function corresponding to the latest call of any methods associated with the function. This function is called by each of the algorithms described later which defined the function Integer Algorithm::StateNumber(). The algorithm has the responsibility to call this function when it has found a solution (i.e. a root or a minimum) and has to maintain the association between the solution found and this StateNumber. Byu default, this method returns 0 (which means for the algorithm: no state has been saved). It is the responsibility of the programmer to decide if he needs to save the current state of the function and to return an Integer that allows retrieval of the state.
        """
    def Value(self,X : float,F : float) -> bool: 
        """
        computes the value <F>of the function for the variable <X>. Returns True if the calculation were successfully done, False otherwise.
        """
    def Values(self,X : float,F : float,D : float) -> bool: 
        """
        computes the value <F> and the derivative <D> of the function for the variable <X>. Returns True if the calculation were successfully done, False otherwise.
        """
    def __init__(self,k0 : int,li : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    pass
class CSLib_NormalStatus():
    """
    if N is the normal

    Members:

      CSLib_Singular

      CSLib_Defined

      CSLib_InfinityOfSolutions

      CSLib_D1NuIsNull

      CSLib_D1NvIsNull

      CSLib_D1NIsNull

      CSLib_D1NuNvRatioIsNull

      CSLib_D1NvNuRatioIsNull

      CSLib_D1NuIsParallelD1Nv
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CSLib_D1NIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NIsNull: 5>
    CSLib_D1NuIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NuIsNull: 3>
    CSLib_D1NuIsParallelD1Nv: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NuIsParallelD1Nv: 8>
    CSLib_D1NuNvRatioIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NuNvRatioIsNull: 6>
    CSLib_D1NvIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NvIsNull: 4>
    CSLib_D1NvNuRatioIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NvNuRatioIsNull: 7>
    CSLib_Defined: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_Defined: 1>
    CSLib_InfinityOfSolutions: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_InfinityOfSolutions: 2>
    CSLib_Singular: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_Singular: 0>
    __entries: dict # value = {'CSLib_Singular': (<CSLib_NormalStatus.CSLib_Singular: 0>, None), 'CSLib_Defined': (<CSLib_NormalStatus.CSLib_Defined: 1>, None), 'CSLib_InfinityOfSolutions': (<CSLib_NormalStatus.CSLib_InfinityOfSolutions: 2>, None), 'CSLib_D1NuIsNull': (<CSLib_NormalStatus.CSLib_D1NuIsNull: 3>, None), 'CSLib_D1NvIsNull': (<CSLib_NormalStatus.CSLib_D1NvIsNull: 4>, None), 'CSLib_D1NIsNull': (<CSLib_NormalStatus.CSLib_D1NIsNull: 5>, None), 'CSLib_D1NuNvRatioIsNull': (<CSLib_NormalStatus.CSLib_D1NuNvRatioIsNull: 6>, None), 'CSLib_D1NvNuRatioIsNull': (<CSLib_NormalStatus.CSLib_D1NvNuRatioIsNull: 7>, None), 'CSLib_D1NuIsParallelD1Nv': (<CSLib_NormalStatus.CSLib_D1NuIsParallelD1Nv: 8>, None)}
    __members__: dict # value = {'CSLib_Singular': <CSLib_NormalStatus.CSLib_Singular: 0>, 'CSLib_Defined': <CSLib_NormalStatus.CSLib_Defined: 1>, 'CSLib_InfinityOfSolutions': <CSLib_NormalStatus.CSLib_InfinityOfSolutions: 2>, 'CSLib_D1NuIsNull': <CSLib_NormalStatus.CSLib_D1NuIsNull: 3>, 'CSLib_D1NvIsNull': <CSLib_NormalStatus.CSLib_D1NvIsNull: 4>, 'CSLib_D1NIsNull': <CSLib_NormalStatus.CSLib_D1NIsNull: 5>, 'CSLib_D1NuNvRatioIsNull': <CSLib_NormalStatus.CSLib_D1NuNvRatioIsNull: 6>, 'CSLib_D1NvNuRatioIsNull': <CSLib_NormalStatus.CSLib_D1NvNuRatioIsNull: 7>, 'CSLib_D1NuIsParallelD1Nv': <CSLib_NormalStatus.CSLib_D1NuIsParallelD1Nv: 8>}
    pass
CSLib_D1IsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1IsNull: 3>
CSLib_D1NIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NIsNull: 5>
CSLib_D1NuIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NuIsNull: 3>
CSLib_D1NuIsParallelD1Nv: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NuIsParallelD1Nv: 8>
CSLib_D1NuNvRatioIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NuNvRatioIsNull: 6>
CSLib_D1NvIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NvIsNull: 4>
CSLib_D1NvNuRatioIsNull: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_D1NvNuRatioIsNull: 7>
CSLib_D1uD1vRatioIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1uD1vRatioIsNull: 4>
CSLib_D1uIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1uIsNull: 1>
CSLib_D1uIsParallelD1v: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1uIsParallelD1v: 6>
CSLib_D1vD1uRatioIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1vD1uRatioIsNull: 5>
CSLib_D1vIsNull: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_D1vIsNull: 2>
CSLib_Defined: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_Defined: 1>
CSLib_Done: OCP.CSLib.CSLib_DerivativeStatus # value = <CSLib_DerivativeStatus.CSLib_Done: 0>
CSLib_InfinityOfSolutions: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_InfinityOfSolutions: 2>
CSLib_Singular: OCP.CSLib.CSLib_NormalStatus # value = <CSLib_NormalStatus.CSLib_Singular: 0>



import OCP.BndLib
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
import OCP.Bnd
import OCP.Geom2d
import OCP.Adaptor2d
import OCP.Adaptor3d
__all__  = [
"BndLib",
"BndLib_Add2dCurve",
"BndLib_Add3dCurve",
"BndLib_AddSurface"
]
class BndLib():
    """
    The BndLib package provides functions to add a geometric primitive to a bounding box. Note: these functions work with gp objects, optionally limited by parameter values. If the curves and surfaces provided by the gp package are not explicitly parameterized, they still have an implicit parameterization, similar to that which they infer for the equivalent Geom or Geom2d objects. Add : Package to compute the bounding boxes for elementary objects from gp in 2d and 3d .
    """
    @staticmethod
    @overload
    def Add_s(L : OCP.gp.gp_Lin,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Bounding box for a surface trimmed or not Adds the segment of the line L limited by the two parameter values P1 and P2, to the bounding box B, and then enlarges B by the tolerance value Tol. Tol is the tolerance value to enlarge the minimum and maximum dimension P1 and P2 may represent infinite values. Exceptions Standard_Failure if P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.

        P2-P1 can be in [0,2*pi]

        Adds the circle C, or the arc of the circle C limited by the two parameter values P1 and P2, to the bounding box B, and then enlarges B by the tolerance value Tol. P2-P1 can be in [0,2*pi]

        P2-P1 can be in [0,2*pi]

        Adds the ellipse E, or the arc of the ellipse E limited by the two parameter values P1 and P2, to the bounding box B, and then enlarges B by the tolerance value Tol. P2-P1 can be in [0,2*pi]

        Adds the arc of the parabola P limited by the two parameter values P1 and P2, to the bounding box B, and then enlarges B by the tolerance value Tol. P1 and P2 may represent infinite values. Exceptions Standard_Failure if P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Adds the arc of the branch of hyperbola H limited by the two parameter values P1 and P2, to the bounding box B, and then enlarges B by the tolerance value Tol. P1 and P2 may represent infinite values. Exceptions Standard_Failure if P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.

        UMax -UMin can be in [0,2*pi]

        Adds to the bounding box B, the patch of the cylinder S limited - in the v parametric direction, by the two parameter values VMin and VMax - and optionally in the u parametric direction, by the two parameter values UMin and UMax. B is then enlarged by the tolerance value Tol. VMin and VMax may represent infinite values. Exceptions Standard_Failure if VMin and VMax are either two negative infinite real numbers, or two positive infinite real numbers.

        UMax-UMin can be in [0,2*pi]

        Adds to the bounding box B, the patch of the cone S limited - in the v parametric direction, by the two parameter values VMin and VMax - and optionally in the u parametric direction, by the two parameter values UMin and UMax, B is then enlarged by the tolerance value Tol. VMin and VMax may represent infinite values. Exceptions Standard_Failure if VMin and VMax are either two negative infinite real numbers, or two positive infinite real numbers.

        Adds to the bounding box B the sphere S, or - the patch of the sphere S, limited in the u parametric direction, by the two parameter values UMin and UMax, and in the v parametric direction, by the two parameter values VMin and VMax. B is then enlarged by the tolerance value Tol. UMax-UMin can be in [0,2*pi] VMin,VMax can be [-pi/2,pi/2]

        Adds to the bounding box B - the torus S, or - the patch of the torus S, limited in the u parametric direction, by the two parameter values UMin and UMax, and in the v parametric direction, by the two parameter values VMin and VMax. B is then enlarged by the tolerance value Tol. UMax-UMin can be in [0,2*pi], VMin,VMax can be [-pi/2,pi/2]
        """
    @staticmethod
    @overload
    def Add_s(L : OCP.gp.gp_Lin2d,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Circ,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Circ,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Circ2d,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Circ2d,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Elips,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Elips,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Elips2d,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.gp.gp_Elips2d,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(P : OCP.gp.gp_Parab,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(P : OCP.gp.gp_Parab2d,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(H : OCP.gp.gp_Hypr,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(H : OCP.gp.gp_Hypr2d,P1 : float,P2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.gp.gp_Cylinder,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.gp.gp_Cylinder,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.gp.gp_Cone,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.gp.gp_Cone,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.gp.gp_Sphere,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.gp.gp_Sphere,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(P : OCP.gp.gp_Torus,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(P : OCP.gp.gp_Torus,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    def __init__(self) -> None: ...
    pass
class BndLib_Add2dCurve():
    """
    Computes the bounding box for a curve in 2d . Functions to add a 2D curve to a bounding box. The 2D curve is defined from a Geom2d curve.
    """
    @staticmethod
    def AddOptimal_s(C : OCP.Geom2d.Geom2d_Curve,U1 : float,U2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: 
        """
        Adds to the bounding box B the part of curve C B is then enlarged by the tolerance value Tol. U1, U2 - the parametric range to compute the bounding box; Note: depending on the type of curve, one of the following algorithms is used to include it in the bounding box B: - an exact analytical if C is built from a line, a circle or a conic curve, - numerical calculation of bounding box sizes, based on minimization algorithm, for other types of curve If Tol = < Precision::PConfusion(), Precision::PConfusion is used as tolerance for calculation
        """
    @staticmethod
    @overload
    def Add_s(C : OCP.Adaptor2d.Adaptor2d_Curve2d,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: 
        """
        Adds to the bounding box B the curve C B is then enlarged by the tolerance value Tol. Note: depending on the type of curve, one of the following representations of the curve C is used to include it in the bounding box B: - an exact representation if C is built from a line, a circle or a conic curve, - the poles of the curve if C is built from a Bezier curve or a BSpline curve, - if not, the points of an approximation of the curve C. Warning C is an adapted curve, that is, an object which is an interface between: - the services provided by a 2D curve from the package Geom2d - and those required of the curve by the computation algorithm. The adapted curve is created in the following way: Handle(Geom2d_Curve) mycurve = ... ; Geom2dAdaptor_Curve C(mycurve); The bounding box B is then enlarged by adding it: Bnd_Box2d B; // ... Standard_Real Tol = ... ; Add2dCurve::Add ( C, Tol, B ); Exceptions Standard_Failure if the curve is built from: - a Geom_Line, or - a Geom_Parabola, or - a Geom_Hyperbola, and P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Adds to the bounding box Bthe arc of the curve C limited by the two parameter values P1 and P2. B is then enlarged by the tolerance value Tol. Note: depending on the type of curve, one of the following representations of the curve C is used to include it in the bounding box B: - an exact representation if C is built from a line, a circle or a conic curve, - the poles of the curve if C is built from a Bezier curve or a BSpline curve, - if not, the points of an approximation of the curve C. Warning C is an adapted curve, that is, an object which is an interface between: - the services provided by a 2D curve from the package Geom2d - and those required of the curve by the computation algorithm. The adapted curve is created in the following way: Handle(Geom2d_Curve) mycurve = ... ; Geom2dAdaptor_Curve C(mycurve); The bounding box B is then enlarged by adding it: Bnd_Box2d B; // ... Standard_Real Tol = ... ; Add2dCurve::Add ( C, Tol, B ); Exceptions Standard_Failure if the curve is built from: - a Geom_Line, or - a Geom_Parabola, or - a Geom_Hyperbola, and P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Adds to the bounding box B the curve C B is then enlarged by the tolerance value Tol. Note: depending on the type of curve, one of the following representations of the curve C is used to include it in the bounding box B: - an exact representation if C is built from a line, a circle or a conic curve, - the poles of the curve if C is built from a Bezier curve or a BSpline curve, - if not, the points of an approximation of the curve C.

        Adds to the bounding box B the part of curve C B is then enlarged by the tolerance value Tol. U1, U2 - the parametric range to compute the bounding box; Note: depending on the type of curve, one of the following representations of the curve C is used to include it in the bounding box B: - an exact representation if C is built from a line, a circle or a conic curve, - the poles of the curve if C is built from a Bezier curve or a BSpline curve, - if not, the points of an approximation of the curve C.
        """
    @staticmethod
    @overload
    def Add_s(C : OCP.Adaptor2d.Adaptor2d_Curve2d,U1 : float,U2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.Geom2d.Geom2d_Curve,Tol : float,Box : OCP.Bnd.Bnd_Box2d) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.Geom2d.Geom2d_Curve,U1 : float,U2 : float,Tol : float,B : OCP.Bnd.Bnd_Box2d) -> None: ...
    def __init__(self) -> None: ...
    pass
class BndLib_Add3dCurve():
    """
    Computes the bounding box for a curve in 3d. Functions to add a 3D curve to a bounding box. The 3D curve is defined from a Geom curve.
    """
    @staticmethod
    def AddGenCurv_s(C : OCP.Adaptor3d.Adaptor3d_Curve,UMin : float,UMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Adds to the bounding box B the curve C using numerical minimization algorithms This method is used in AddOptimal for not analytical curves. if Tol < Precision::Confusion(), Precision:;Confusion is used as computation tolerance
        """
    @staticmethod
    @overload
    def AddOptimal_s(C : OCP.Adaptor3d.Adaptor3d_Curve,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Adds to the bounding box B the curve C These methods use more precise algorithms for building bnd box then methods Add(...)
        """
    @staticmethod
    @overload
    def AddOptimal_s(C : OCP.Adaptor3d.Adaptor3d_Curve,U1 : float,U2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(C : OCP.Adaptor3d.Adaptor3d_Curve,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Adds to the bounding box B the curve C B is then enlarged by the tolerance value Tol. Note: depending on the type of curve, one of the following representations of the curve C is used to include it in the bounding box B: - an exact representation if C is built from a line, a circle or a conic curve, - the poles of the curve if C is built from a Bezier curve or a BSpline curve, if not, the points of an approximation of the curve C. Warning C is an adapted curve, that is, an object which is an interface between: - the services provided by a 3D curve from the package Geom - and those required of the curve by the computation algorithm. The adapted curve is created in the following way: Handle(Geom_Curve) mycurve = ... ; GeomAdaptor_Curve C(mycurve); The bounding box B is then enlarged by adding it: Bnd_Box B; // ... Standard_Real Tol = ... ; Add3dCurve::Add ( C, Tol, B ); Exceptions Standard_Failure if the curve is built from: - a Geom_Line, or - a Geom_Parabola, or - a Geom_Hyperbola, and P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.

        Adds to the bounding box B the curve C the arc of the curve C limited by the two parameter values P1 and P2. Note: depending on the type of curve, one of the following representations of the curve C is used to include it in the bounding box B: - an exact representation if C is built from a line, a circle or a conic curve, - the poles of the curve if C is built from a Bezier curve or a BSpline curve, if not, the points of an approximation of the curve C. Warning C is an adapted curve, that is, an object which is an interface between: - the services provided by a 3D curve from the package Geom - and those required of the curve by the computation algorithm. The adapted curve is created in the following way: Handle(Geom_Curve) mycurve = ... ; GeomAdaptor_Curve C(mycurve); The bounding box B is then enlarged by adding it: Bnd_Box B; // ... Standard_Real Tol = ... ; Add3dCurve::Add ( C, Tol, B ); Exceptions Standard_Failure if the curve is built from: - a Geom_Line, or - a Geom_Parabola, or - a Geom_Hyperbola, and P1 and P2 are either two negative infinite real numbers, or two positive infinite real numbers.
        """
    @staticmethod
    @overload
    def Add_s(C : OCP.Adaptor3d.Adaptor3d_Curve,U1 : float,U2 : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    def __init__(self) -> None: ...
    pass
class BndLib_AddSurface():
    """
    computes the box from a surface Functions to add a surface to a bounding box. The surface is defined from a Geom surface.
    """
    @staticmethod
    def AddGenSurf_s(S : OCP.Adaptor3d.Adaptor3d_Surface,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Adds to the bounding box B the surface S using numerical minimization algorithms This method is used in AddOptimal for not analytical surfaces and torus. if Tol < Precision::Confusion(), Precision::Confusion is used as computation tolerance
        """
    @staticmethod
    @overload
    def AddOptimal_s(S : OCP.Adaptor3d.Adaptor3d_Surface,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Adds the surface S to the bounding box B. This algorithm builds precise bounding box
        """
    @staticmethod
    @overload
    def AddOptimal_s(S : OCP.Adaptor3d.Adaptor3d_Surface,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    @staticmethod
    @overload
    def Add_s(S : OCP.Adaptor3d.Adaptor3d_Surface,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: 
        """
        Adds to the bounding box B the surface S B is then enlarged by the tolerance value Tol. Note: depending on the type of curve, one of the following representations of the surface S is used to include it in the bounding box B: - an exact representation if S is built from a plane, a cylinder, a cone, a sphere or a torus, - the poles of the surface if S is built from a Bezier surface or a BSpline surface, - the points of an approximation of the surface S in cases other than offset surfaces; - in the case of an offset surface, the basis surface is first included according to the previous rules; then the bounding box is enlarged by the offset value. Warning Do not use these functions to add a non-finite surface to the bounding box B. If UMin, UMax, VMin or VMax is an infinite value B will become WholeSpace. S is an adapted surface, that is, an object which is an interface between: - the services provided by a surface from the package Geom - and those required of the surface by the computation algorithm. The adapted surface is created in the following way: Handle(Geom_Surface) mysurface = ... ; GeomAdaptor_Surface S(mysurface); The bounding box B is then enlarged by adding this surface: Bnd_Box B; // ... Standard_Real Tol = ... ; AddSurface::Add ( S, Tol, B );

        Adds to the bounding box B the surface S the patch of the surface S limited in the u parametric direction by the two parameter values UMin, UMax, and in the v parametric direction by the two parameter values VMin, VMax. Note: depending on the type of curve, one of the following representations of the surface S is used to include it in the bounding box B: - an exact representation if S is built from a plane, a cylinder, a cone, a sphere or a torus, - the poles of the surface if S is built from a Bezier surface or a BSpline surface, - the points of an approximation of the surface S in cases other than offset surfaces; - in the case of an offset surface, the basis surface is first included according to the previous rules; then the bounding box is enlarged by the offset value. Warning Do not use these functions to add a non-finite surface to the bounding box B. If UMin, UMax, VMin or VMax is an infinite value B will become WholeSpace. S is an adapted surface, that is, an object which is an interface between: - the services provided by a surface from the package Geom - and those required of the surface by the computation algorithm. The adapted surface is created in the following way: Handle(Geom_Surface) mysurface = ... ; GeomAdaptor_Surface S(mysurface); The bounding box B is then enlarged by adding this surface: Bnd_Box B; // ... Standard_Real Tol = ... ; AddSurface::Add ( S, Tol, B );
        """
    @staticmethod
    @overload
    def Add_s(S : OCP.Adaptor3d.Adaptor3d_Surface,UMin : float,UMax : float,VMin : float,VMax : float,Tol : float,B : OCP.Bnd.Bnd_Box) -> None: ...
    def __init__(self) -> None: ...
    pass
